@@ -25,11 +25,35 @@ class Game:
     def __dice_generator(self):
         self.current_dice = np.random.randint(1, 6 + 1)
 
+    def get_pieces(self, seen_from=None):
+        """
+        Returns the pieces places on the board
+
+        :param seen_from: indicate which player the pieces and enemy pieces are seen from. If None then the pieces
+        from all 4 player are given and no enemy pieces
+        :return pieces: The pieces for alle the players (if seen_from = None) else the pieces for the
+        player given in seen_from
+        :return enemy_pieces: The pieces of the enemys if a player is given in seen_from
+        """
+        if seen_from is None:
+            pieces = [p.get_pieces() for p in self.players]
+            enemy_pieces = None
+        else:
+            assert 1 <= seen_from <= 4, "The seen_from has to be between 1 and 4. Indicating the player the pieces are seen from and the nemys are seen from"
+            # Get where the players piece are
+            pieces = self.players[seen_from].get_pieces()
+            # Get where the enemy's piece are
+            enemy_pieces = [self.players[e].get_pieces() for e in self.enemys_order[seen_from]]
+        return np.array(pieces), np.array(enemy_pieces)
+
     def __add_to_hist(self):
-        pieces = [p.get_pieces() for p in self.players]
+        pieces = self.get_pieces()
         self.hist.append([pieces, self.current_dice, self.current_player+1, self.round])
 
     def reset(self):
+        """
+        Resets the game and the game history
+        """
         self.players = [Player(), Player(), Player(), Player()]
         self.hist = []
 
@@ -42,10 +66,9 @@ class Game:
         # Get the pieces there can be moved with the current dice
         move_pieces = player.get_pieces_that_can_move(dice)
         self.current_move_pieces = move_pieces
-        # Get where the players piece are
-        player_pieces = player.get_pieces()
-        # Get where the enemy's piece are
-        enemy_pieces = [self.players[e].get_pieces() for e in self.enemys_order[player_idx]]
+
+        # Get where the players piece are and the enemy's piece are
+        player_pieces, enemy_pieces = self.get_pieces(player_idx)
         self.current_enemys = enemy_pieces
         # Check if the player is a winner
         player_is_a_winner = player.player_winner()
@@ -60,8 +83,13 @@ class Game:
 
     def get_observation(self):
         """
+        Return the state/observation of the game and which players turn it is
+        A given observation has to be answered before a new one can be given.
 
-        :return: (dice, move_pieces, player_pieces, enemy_pieces, player_is_a_winner, there_is_a_winner), current_player
+        :return obs: The observation taken of the state of the game seen from the player
+        given in the return current_player (dice, move_pieces, player_pieces, enemy_pieces,
+        player_is_a_winner, there_is_a_winner)
+        :return current_player: Which players turn it is
         """
         # Check if there is a observation pending
         if self.observation_pending:
@@ -86,8 +114,11 @@ class Game:
 
     def answer_observation(self, piece_to_move):
         """
+        Answers a observation. A observation has to be given before a answer can be given.
 
-        :return: dice, move_pieces, player_pieces, enemy_pieces, player_is_a_winner, there_is_a_winner
+        :param piece_to_move: Which piece to move. If there was no pieces there cloud be moved the parameter is ignored
+        :return obs: Who the game was after the given move was done
+        (dice, move_pieces, player_pieces, enemy_pieces, player_is_a_winner, there_is_a_winner)
         """
         # Check if there is a observation pending
         if not self.observation_pending:
@@ -138,20 +169,43 @@ class Game:
 
     def get_hist(self):
         """
+        Returns the history there has been recorded during the game. This history can be used to make
+        a video of the game. The history will have been extended when a observation was given and when a
+        answer to a observation was given.
+
         :returns list of [pieces, current_dice, first_winner_was, current_player, round]
         """
         return self.hist
 
     def render_environment(self):
+        """
+        Will render the last record in the history
+
+        :return board_img: A image of the board
+        """
         board_img = make_img_of_board(*self.hist[-1])
         return board_img
 
     def save_hist(self, file_name):
+        """
+        Saves the history of the game as a npy file
+
+        :param file_name: The file name to save under. Has to have the .npy (numpy file) extension
+        """
         file_ext = file_name.split(".")[-1]
         assert file_ext == "npy", "The file extension has to be npy (numpy file)"
         np.save(file_name, self.hist)
 
     def save_hist_video(self, video_out, fps=8, frame_size=None, fourcc=None):
+        """
+        Saves a video of the game history
+
+        :param video_out: The file name to save under
+        :param fps: Frames per second
+        :param frame_size: The frame size to save in (width, height). If None is given the full board size is used
+        :param fourcc: FourCC code to be used.
+        If None is given the FourCC code will be tried to create fro the file extension (works on .mp4 and .avi)
+        """
         save_hist_video(video_out, self.hist, fps=fps, frame_size=frame_size, fourcc=fourcc)
 
 
